@@ -38,10 +38,11 @@ changevar.prop <- function(catvar.levels, catvar1, catvar2, wgt, x, y,
 #   y = y-coordinate for location for each site, which is either the y-
 #     coordinate for a single-stage sample or the stage two y-coordinate for a
 #     two-stage sample.
-#   revisitwgt = a logical value that indicates whether the revisited sites in
-#     the two surveys have the same survey design weights, where TRUE = the
+#   revisitwgt = a logical value that indicates whether the repeat visit sites
+#     in the two surveys have the same survey design weights, where TRUE = the
 #     weights are the same and FALSE = the weights are not the same.  When this
-#     argument is FALSE, the revisited sites have been assigned equal weights.
+#     argument is FALSE, the repeat visit sites have been assigned equal
+#     weights.
 #   prop1 = the set of category proportion estimates for survey one.
 #   prop2 = the set of category proportion estimates for survey two.
 #   stratum.ind = a logical value that indicates whether the sample is
@@ -140,15 +141,15 @@ if(cluster.ind) {
 # Determine whether the categorical level is present in both surveys
       if(is.na(prop1[k]) | is.na(prop2[k])) {
          warn.ind <- TRUE
-         act <- "Covariance among the revisited sites was not included in calculation of \nthe standard error estimate.\n"
+         act <- "Covariance among the repeat visit sites was not included in calculation of \nthe standard error estimate.\n"
          if(stratum.ind) {
-            warn <- paste("Category level \"", catvar.levels[k], "\" in stratum \"", stratum.level, "\" \nwas not present in one of the surveys.\n", sep="")
+            warn <- paste("Category level \"", catvar.levels[k], "\" in stratum \"", stratum.level, "\" \nwas not present among the repeat visit sites in one of the surveys.\n", sep="")
             warn.df <- rbind(warn.df, data.frame(func=I(fname),
                subpoptype=warn.vec[1], subpop=warn.vec[2],
                indicator=warn.vec[3], stratum=I(stratum.level), warning=I(warn),
                action=I(act)))
          } else {
-            warn <- paste("Category level \"", catvar.levels[k], "\" was not present in one of the surveys.\n", sep="")
+            warn <- paste("Category level \"", catvar.levels[k], "\" was not present among the repeat visit sites \nin one of the surveys.\n", sep="")
             warn.df <- rbind(warn.df, data.frame(func=I(fname),
                subpoptype=warn.vec[1], subpop=warn.vec[2],
                indicator=warn.vec[3], stratum=NA, warning=I(warn),
@@ -180,13 +181,13 @@ if(cluster.ind) {
             warn.ind <- TRUE
             act <- "The simple random sampling variance estimator was used.\n"
             if(stratum.ind) {
-               warn <- paste("There are less than four response values for stage one sampling unit ", cluster.levels[i], "\nin stratum ", stratum.level, ", the simple random sampling variance estimator \nwas used to calculate variance of the estimate.\n", sep="")
+               warn <- paste("There are less than four response values for stage one sampling unit ", cluster.levels[i], "\nin stratum ", stratum.level, ", the simple random sampling variance estimator \nwas used to calculate covariance of the estimate.\n", sep="")
                warn.df <- rbind(warn.df, data.frame(func=I(fname),
                   subpoptype=warn.vec[1], subpop=warn.vec[2],
                   indicator=warn.vec[3], stratum=I(stratum.level),
                   warning=I(warn), action=I(act)))
             } else {
-               warn <- paste("There are less than four response values for stage one sampling unit ", cluster.levels[i], ", \nthe simple random sampling variance estimator was used to calculate variance of \nthe estimate.\n", sep="")
+               warn <- paste("There are less than four response values for stage one sampling unit ", cluster.levels[i], ", \nthe simple random sampling variance estimator was used to calculate covariance of \nthe estimate.\n", sep="")
                warn.df <- rbind(warn.df, data.frame(func=I(fname),
                   subpoptype=warn.vec[1], subpop=warn.vec[2],
                   indicator=warn.vec[3], stratum=NA, warning=I(warn),
@@ -228,13 +229,13 @@ if(cluster.ind) {
          warn.ind <- TRUE
          act <- "The simple random sampling variance estimator was used.\n"
          if(stratum.ind) {
-            warn <- paste("There are less than four stage one sampling units in stratum ", stratum.level, ", \nthe simple random sampling variance estimator was used to calculate variance of \nthe estimate.\n", sep="")
+            warn <- paste("There are less than four stage one sampling units in stratum ", stratum.level, ", \nthe simple random sampling variance estimator was used to calculate covariance of \nthe estimate.\n", sep="")
             warn.df <- rbind(warn.df, data.frame(func=I(fname),
                subpoptype=warn.vec[1], subpop=warn.vec[2],
                indicator=warn.vec[3], stratum=I(stratum.level), warning=I(warn),
                action=I(act)))
          } else {
-            warn <- paste("There are less than four stage one sampling units, the simple random sampling \nvariance estimator was used to calculate variance of the estimate.\n", sep="")
+            warn <- paste("There are less than four stage one sampling units, the simple random sampling \nvariance estimator was used to calculate covariance of the estimate.\n", sep="")
             warn.df <- rbind(warn.df, data.frame(func=I(fname),
                subpoptype=warn.vec[1], subpop=warn.vec[2],
                indicator=warn.vec[3], stratum=NA, warning=I(warn),
@@ -283,15 +284,15 @@ if(cluster.ind) {
 # Determine whether the categorical level is present in both surveys
       if(is.na(prop1[i]) | is.na(prop2[i])) {
          warn.ind <- TRUE
-         act <- "Covariance among the revisited sites was not included in calculation of \nthe standard error estimate.\n"
+         act <- "Covariance among the repeat visit sites was not included in calculation of \nthe standard error estimate.\n"
          if(stratum.ind) {
-            warn <- paste("Category level \"", catvar.levels[i], "\" in stratum \"", stratum.level, "\" \nwas not present in one of the surveys.\n", sep="")
+            warn <- paste("Category level \"", catvar.levels[i], "\" in stratum \"", stratum.level, "\" \nwas not present among the repeat visit sites in one of the surveys.\n", sep="")
             warn.df <- rbind(warn.df, data.frame(func=I(fname),
                subpoptype=warn.vec[1], subpop=warn.vec[2],
                indicator=warn.vec[3], stratum=I(stratum.level), warning=I(warn),
                action=I(act)))
          } else {
-            warn <- paste("Category level \"", catvar.levels[i], "\" was not present in one of the surveys.\n", sep="")
+            warn <- paste("Category level \"", catvar.levels[i], "\" was not present among the repeat visit sites \nin one of the surveys.\n", sep="")
             warn.df <- rbind(warn.df, data.frame(func=I(fname),
                subpoptype=warn.vec[1], subpop=warn.vec[2],
                indicator=warn.vec[3], stratum=NA, warning=I(warn),
@@ -312,13 +313,13 @@ if(cluster.ind) {
          warn.ind <- TRUE
          act <- "The simple random sampling variance estimator was used.\n"
          if(stratum.ind) {
-            warn <- paste("There are less than four response values in stratum ", stratum.level, ", \nthe simple random sampling variance estimator was used to calculate variance of \nthe estimate.\n", sep="")
+            warn <- paste("There are less than four response values in stratum ", stratum.level, ", \nthe simple random sampling variance estimator was used to calculate covariance of \nthe estimate.\n", sep="")
             warn.df <- rbind(warn.df, data.frame(func=I(fname),
                subpoptype=warn.vec[1], subpop=warn.vec[2],
                indicator=warn.vec[3], stratum=I(stratum.level), warning=I(warn),
                action=I(act)))
          } else {
-            warn <- "\nThere are less than four response values, the simple random sampling variance \nestimator was used to calculate variance of the estimate.\n"
+            warn <- "\nThere are less than four response values, the simple random sampling variance \nestimator was used to calculate covariance of the estimate.\n"
             warn.df <- rbind(warn.df, data.frame(func=I(fname),
                subpoptype=warn.vec[1], subpop=warn.vec[2],
                indicator=warn.vec[3], stratum=NA, warning=I(warn),
@@ -342,7 +343,7 @@ if(cluster.ind) {
       } else {
          if(varest[1,1] == 0 | varest[2,2] == 0) {
             warn.ind <- TRUE
-            act <- "Covariance among the revisited sites was not included in calculation of \nthe standard error estimate.\n"
+            act <- "Covariance among the repeat visit sites was not included in calculation of \nthe standard error estimate.\n"
             if(stratum.ind) {
                warn <- paste("The variance estimate for category level \"", catvar.levels[i], "\" \nin stratum \"", stratum.level, "\" was equal to zero for at least one of the surveys.\n", sep="")
                warn.df <- rbind(warn.df, data.frame(func=I(fname),
